Learn R Programming

BCSreg (version 1.1.1)

influence: Influence Diagnostics for BCSreg Objects

Description

The influence function provides two influence measures for a Box-Cox symmetric or a zero-adusted Box-Cox symmetric regression fit.

Usage

influence(object, plot = TRUE, ask = grDevices::dev.interactive(), ...)

Value

influence returns a list with two objects:

case.weights

The values of \(d_{max}\) eigenvector based on case weights perturbation scheme (see Medeiros and Queiroz (2025)).

totalLI

The total local influence (see Lesaffre and Verbeke (1998)).

Arguments

object

an object of class "BCSreg".

plot

logical. If plot = TRUE (default), the plots are shown.

ask

logical; if TRUE, the user is asked before each plot, if plot = TRUE.

...

currently not used.

Author

Francisco F. de Queiroz <felipeq@ime.usp.br>

Rodrigo M. R. de Medeiros <rodrigo.matheus@ufrn.br>

References

Lesaffre, E., and Verbeke, G. (1998). Local influence in linear mixed models. Biometrics, 570--582.

Medeiros, R. M. R., and Queiroz, F. F. (2025). Flexible modeling of nonnegative continuous data: Box-Cox symmetric regression and its zero-adjusted extension.

See Also

BCSreg for parameter estimation in the class of the Box-Cox symmetric or zero-adjusted Box-Cox symmetric regression models, residuals.BCSreg for extracting residuals for a fitted model, and plot.BCSreg for diagnostic plots.

Examples

Run this code
## Data set: raycatch (for description, run ?raycatch)
hist(raycatch$cpue, xlab = "Catch per unit effort")
plot(cpue ~ tide_phase, raycatch, pch = 16,
   xlab = "Tide phase", ylab = "Catch per unit effort")
plot(cpue ~ location, raycatch, pch = 16,
   xlab = "Location", ylab = "Catch per unit effort")
plot(cpue ~ max_temp, raycatch, pch = 16,
   xlab = "Maximum temperature", ylab = "Catch per unit effort")

## Fit a double Box-Cox normal regression model:
fit <- BCSreg(cpue ~ location + tide_phase |
               location + tide_phase + max_temp, raycatch)

## Influence measures under case-weights perturbation scheme:
cw <- influence(fit) ## two index plots are shown
str(cw)

Run the code above in your browser using DataLab