Learn R Programming

BCSreg (version 1.1.1)

renewables2015: Renewable Electricity Output for 186 Countries (2015)

Description

This dataset provides information on renewable electricity output and a set of socioeconomic, environmental, and institutional variables for 186 countries in the year 2015. The data were obtained from the World Bank (https://data.worldbank.org/).

Usage

data(renewables2015)

Arguments

Format

A data frame with 186 rows and 9 variables:

country_name

country name.

adj_sav_edu

adjusted savings: education expenditure (percent of GNI).

agri_land

natural logarithm of total agricultural land area (in sq. km).

elec_fossil

electricity production from fossil fuels (percent of total). Indicates the share of electricity generated from oil, gas, and coal, representing reliance on non-renewable energy.

forest_area

forest area (percent of land area). Reflects natural resource availability.

gov_effec

government effectiveness index (range: approximately -2.5 to 2.5). Measures public service quality, policy implementation, and government credibility.

pop_density

natural logarithm of population density (people per sq. km).

access_elec

access to electricity (percent of population).

renew_elec_output

renewable electricity output (in TWh).

Details

The response variable is the renewable electricity output, measured in terawatt-hours (TWh), representing the total electricity generated from renewable sources such as wind, solar photovoltaic, solar thermal, hydro, marine, geothermal, solid biofuels, renewable municipal waste, liquid biofuels, and biogas. Hydro pumped storage is excluded.

Examples

Run this code
data(renewables2015)
summary(renewables2015)
pairs(renewables2015[, -1], pch = 16, cex = 0.8, col = rgb(0,0,0, 0.5))

Run the code above in your browser using DataLab